@@ -13,7 +13,7 @@
 #
 # See the README file for information on usage and redistribution.
 #
-
+from __future__ import annotations
 
 from . import Image, ImageFile
 
@@ -24,18 +24,19 @@ from . import Image, ImageFile
 
 
 class PcdImageFile(ImageFile.ImageFile):
-
     format = "PCD"
     format_description = "Kodak PhotoCD"
 
-    def _open(self):
-
+    def _open(self) -> None:
         # rough
+        assert self.fp is not None
+
         self.fp.seek(2048)
         s = self.fp.read(2048)
 
         if s[:4] != b"PCD_":
-            raise SyntaxError("not a PCD file")
+            msg = "not a PCD file"
+            raise SyntaxError(msg)
 
         orientation = s[1538] & 3
         self.tile_post_rotate = None
@@ -44,13 +45,15 @@ class PcdImageFile(ImageFile.ImageFile):
         elif orientation == 3:
             self.tile_post_rotate = -90
 
-        self.mode = "RGB"
+        self._mode = "RGB"
         self._size = 768, 512  # FIXME: not correct for rotated images!
         self.tile = [("pcd", (0, 0) + self.size, 96 * 2048, None)]
 
-    def load_end(self):
+    def load_end(self) -> None:
         if self.tile_post_rotate:
             # Handle rotated PCDs
+            assert self.im is not None
+
             self.im = self.im.rotate(self.tile_post_rotate)
             self._size = self.im.size
 
